Leo 6.2.1, http://leoeditor.com, is now available on [GitHub](https://github.com/leo-editor/leo-editor).

Leo is an [IDE, outliner and PIM](http://leoeditor.com/preface.html).

**The highlights of Leo 6.2**

- Added the fstringify-files and diff-fstringify-files commands.
- Improved the beautify-files command. Added the diff-beautify-files commands.
- Added the TokenOrderGenerator and TokenOrderTraverser classes in leoAst.py.
  Leo's fstringify and beautify commands use these classes.
- Added importers for the rust language and todo.txt files.
- Added the viewrendered3 plugin.
- Leo's legacy layout is now the default.
- Fixed all known bugs, including some notable, long-standing bugs.
- Fixed several "fit and finish" issues.
- Removed unused settings from leoSettings.leo.

**Links**

- Leo's home page: http://leoeditor.com
- [Documentation](http://leoeditor.com/leo_toc.html)
- [Tutorials](http://leoeditor.com/tutorial.html)
- [Video tutorials](http://leoeditor.com/screencasts.html)
- [Forum](http://groups.google.com/group/leo-editor)
- [Download](http://sourceforge.net/projects/leo/files/)
- [Leo on GitHub](https://github.com/leo-editor/leo-editor)
- [LeoVue](https://github.com/kaleguy/leovue#leo-vue)
- [What people are saying about Leo](http://leoeditor.com/testimonials.html)
- [A web page that displays .leo files](http://leoeditor.com/load-leo.html)
- [More links](http://leoeditor.com/leoLinks.html)
